#[repr(transparent)]pub struct HMEventTriggerActivationState(pub NSUInteger);Available on crate feature
HMEventTriggerActivationState only.Expand description
This enumeration describes the current activation state of the event trigger.
See also Apple’s documentation
Tuple Fields
0: NSUIntegerImplementations
Sourceimpl HMEventTriggerActivationState
impl HMEventTriggerActivationState
Sourcepub const DisabledNoHomeHub: Self
pub const DisabledNoHomeHub: Self
Trigger is not active because there is no HomeHub
Sourcepub const DisabledNoCompatibleHomeHub: Self
pub const DisabledNoCompatibleHomeHub: Self
Trigger is not active because there is no compatible HomeHub
Sourcepub const DisabledNoLocationServicesAuthorization: Self
pub const DisabledNoLocationServicesAuthorization: Self
Trigger is not active because Location Authorization has been turned off by user